# coding: utf-8

from django.core.urlresolvers import reverse_lazy

from novaclient.exceptions import ClientException

from tionix_dashboard.clients.base import TNXBaseNovaClient
from tionix_dashboard.clients.helpers import expected_402_404
from tionix_dashboard.dashboards.license import LicenseController
from tionix_dashboard.url_resolve_map import HYPERVISORS_INDEX


class TNXHypervisorsClient(TNXBaseNovaClient):
    """Client for tnx hypervisors"""

    resource = 'tnx_hypervisors'

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def count(cls, request, **kwargs):
        return super(TNXHypervisorsClient, cls).count(request, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def get(cls, request, identifier):
        return super(TNXHypervisorsClient, cls).get(request, identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def list(cls, request, **kwargs):
        return super(TNXHypervisorsClient, cls).list(request, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def update(cls, request, identifier, **kwargs):
        return super(TNXHypervisorsClient, cls).update(
            request, identifier, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def search(cls, request, query, servers=True):
        return cls.get_resource(request).search(query, servers)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def set_default_power_device_for_node(
            cls, request, node_id, power_device_id):
        _response, body = (
            cls.get_resource(request).set_default_power_device_for_node(
                node_id, power_device_id))
        if not body['success']:
            raise ClientException(code=None, message=body['message'])

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def set_power_device_port_for_node(
            cls, request, node_id, power_device_id, power_device_port):
        _response, body = (
            cls.get_resource(request).set_power_device_port_for_node(
                node_id, power_device_id, power_device_port))
        if not body['success']:
            raise ClientException(code=None, message=body['message'])

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def shut_down_hypervisor(
            cls, request, node_id, allow_off_vm=False, allow_evacuate=False):
        return cls.get_client(request).hosts.shutdown(
            node_id, allow_off_vm, allow_evacuate)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def assign_hypervisor_image(cls, request, node_id, image_id):
        result, body = cls.get_resource(request).assign_node_image(node_id,
                                                                   image_id)
        if body and not body['success']:
            raise ClientException(code=None, message=body['message'])
        return result

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def set_reserved_flag_hypervisor(cls, request, node_id, flag):
        result, body = cls.get_resource(request).set_node_reserved_flag(
            node_id, flag)
        if not body['success']:
            raise ClientException(code=None, message=body['message'])
        return result

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def reset_hypervisor(cls, request, identifier):
        return cls.get_resource(request).reset(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def power_on_hypervisor(cls, request, identifier):
        return cls.get_resource(request).power_on(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def power_off_hypervisor(cls, request, identifier):
        return cls.get_resource(request).power_off(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def reset(cls, request, identifier):
        return cls.get_resource(request).reset(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def reset_all(cls, request, hypervisor_ids):
        return cls.get_resource(request).reset_all(hypervisor_ids)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def get_power_actions(cls, request, identifier):
        return cls.get_resource(request).get_power_actions(identifier)
