# coding: utf-8

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, workflows

from openstack_dashboard import api
from openstack_dashboard.dashboards.admin.flavors import views as admin_views

from novaclient.exceptions import NotFound

from tionix_dashboard.dashboards.admin.flavors.tables import FlavorsTable
from tionix_dashboard.dashboards.admin.flavors.workflows import (
    ModifyAccessFlavor, UpdateFlavor, CreateFlavor)


logger = logging.getLogger(__name__)


class IndexView(admin_views.IndexView):
    table_class = FlavorsTable


class ModifyAccessView(workflows.WorkflowView):
    workflow_class = ModifyAccessFlavor

    def get_initial(self):
        initial = super(ModifyAccessView, self).get_initial()
        flavors = []
        for flavor_id in self.request.GET.getlist('id', []):
            try:
                flavor = api.nova.flavor_get(self.request, flavor_id)
                flavors.append((flavor.id, flavor.name))
            except Exception as err:
                logger.error(err)
                continue
        if flavors:
            self.request.session['flavors'] = flavors
        else:
            flavors = self.request.session.pop('flavors', [])
        initial['flavors'] = flavors
        return initial


class UpdateView(admin_views.UpdateView):
    workflow_class = UpdateFlavor

    def get_initial(self):
        initial = super(UpdateView, self).get_initial()

        flavor_id, flavor_access = self.kwargs['id'], []
        try:
            flavor_access = [project.tenant_id for project in
                             api.nova.flavor_access_list(self.request,
                                                         flavor_id)]
        except NotFound:
            pass
        except Exception as err:
            logger.error(err)
            exceptions.handle(self.request,
                              _('Unable to retrieve flavor access list. '
                                'Please try again later.'))

        initial['flavor_access'] = flavor_access
        return initial


class CreateView(admin_views.CreateView):
    workflow_class = CreateFlavor
