# coding: utf-8
from mock import mock

from tionix_dashboard.dashboards.admin.hypervisors.tables import (
    TnxAdminHypervisorsTable, AdminHypervisorsTable)
from tionix_dashboard.dashboards.tionix.scheduler.helpers import (
    SchedulingPreChecker)
from tionix_dashboard.tests.helpers import BaseAdminClientTestCase


class TnxAdminHypervisorsTableTestCase(BaseAdminClientTestCase):

    def test(self):
        hypervisor = self.tnx_hypervisors.get(1)

        table = TnxAdminHypervisorsTable(request=None)

        self.assertEqual(table.get_object_display(hypervisor),
                         hypervisor.hypervisor_hostname)
        self.assertTrue(table.needs_form_wrapper)
        self.assertIsNone(table.calculate_row_status(None))
        self.assertEqual(
            table.get_row_status_class({}),
            u'tnx_state_cell_green tnx_power_state_cell_green')
        self.assertEqual(
            table.get_row_status_class({'state': False}),
            u'tnx_state_cell_orange tnx_power_state_cell_green')
        self.assertEqual(
            table.get_row_status_class({'power_state': False}),
            u'tnx_state_cell_green tnx_power_state_cell_orange')
        self.assertEqual(
            table.get_row_status_class({'state': False, 'power_state': True}),
            u'red_color')

    def test_no_tnx(self):
        hypervisor = self.tnx_hypervisors.get(5)

        table = TnxAdminHypervisorsTable(request=None)

        self.assertEqual(table.get_object_display(hypervisor),
                         hypervisor.hypervisor_hostname)
        self.assertTrue(table.needs_form_wrapper)
        self.assertIsNone(table.calculate_row_status(None))
        self.assertEqual(
            table.get_row_status_class({}),
            u'tnx_state_cell_green tnx_power_state_cell_green')
        self.assertEqual(
            table.get_row_status_class({'state': False}),
            u'tnx_state_cell_orange tnx_power_state_cell_green')
        self.assertEqual(
            table.get_row_status_class({'power_state': False}),
            u'tnx_state_cell_green tnx_power_state_cell_orange')
        self.assertEqual(
            table.get_row_status_class({'state': False, 'power_state': True}),
            u'red_color')

    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_tnx_table_actions_list(self):
        hypervisors = self.tnx_hypervisors.list()
        table = TnxAdminHypervisorsTable(self.request, data=hypervisors)

        self.assertListEqual(
            [action.name for action in table.get_table_actions()],
            ['filter_admin_hypervisors', 'power_on', 'multi_shutdown',
             'multi_power_off', 'multi_restart', 'multi_markreserved',
             'multi_assign_image', 'multi_schedule_calendar', 'multi_update']
        )

    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_tnx_row_actions_list(self):
        table = TnxAdminHypervisorsTable(self.request)
        # Hypervisor with state - up, tnx_power_state - None
        hypervisor = self.tnx_hypervisors.get(1)
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['hypervisors', 'schedule_calendar', 'restart', 'update'])
        )
        # Hypervisor with state - up, tnx_power_state - power_on
        hypervisor = self.tnx_hypervisors.get(2)
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['hypervisors', 'shutdown', 'schedule_calendar', 'restart',
                    'power_off', 'update', 'markreserved'])
        )
        # Hypervisor with state - down, tnx_power_state - None
        hypervisor = self.tnx_hypervisors.get(3)
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['hypervisors', 'schedule_calendar', 'power_on', 'update'])
        )
        # Hypervisor with state - down, tnx_power_state - power_off
        hypervisor = self.tnx_hypervisors.get(4)
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['hypervisors', 'schedule_calendar', 'power_on', 'update'])
        )

    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_tnx_row_actions_list_no_tnx(self):
        table = TnxAdminHypervisorsTable(self.request)
        # Hypervisor with state - up, tnx_power_state - None
        hypervisor = self.tnx_hypervisors.list()[4]
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['hypervisors', 'schedule_calendar', 'update'])
        )
        # Hypervisor with state - up, tnx_power_state - power_on
        hypervisor = self.tnx_hypervisors.list()[5]
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['hypervisors', 'schedule_calendar', 'update'])
        )
        # Hypervisor with state - down, tnx_power_state - None
        hypervisor = self.tnx_hypervisors.list()[6]
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['hypervisors', 'schedule_calendar', 'update'])
        )
        # Hypervisor with state - down, tnx_power_state - power_off
        hypervisor = self.tnx_hypervisors.list()[7]
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['hypervisors', 'schedule_calendar', 'update'])
        )

    def test_tnx_columns_list(self):
        table = TnxAdminHypervisorsTable(self.request)

        self.assertListEqual(
            table.columns.keys(),
            ['multi_select', 'hostname', 'node_title', 'hypervisor_type',
             'image', 'state', 'power_state', 'is_reserved', 'running_vms',
             'actions']
        )

    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_table_actions_list(self):
        hypervisors = self.tnx_hypervisors.list()
        table = AdminHypervisorsTable(self.request, data=hypervisors)

        self.assertListEqual(
            [action.name for action in table.get_table_actions()],
            ['multi_schedule_calendar']
        )

    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_row_actions_list(self):
        table = AdminHypervisorsTable(self.request)

        hypervisor = self.hypervisors.first()
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(hypervisor)]),
            sorted(['schedule_calendar'])
        )

    def test_columns_list(self):
        table = AdminHypervisorsTable(self.request)

        self.assertListEqual(
            table.columns.keys(),
            ['multi_select', 'hostname', 'hypervisor_type', 'vcpus_used',
             'vcpus', 'memory_used', 'memory', 'local_used', 'local',
             'running_vms', 'actions']
        )
