# coding: utf-8

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import forms, messages

from openstack_dashboard import api
from openstack_dashboard.dashboards.admin.images import forms as images_forms
from tionix_dashboard.helpers.fields import AutoGenNameCharField


logger = logging.getLogger(__name__)


class MultiImageEditForm(forms.SelfHandlingForm):
    is_public = forms.BooleanField(label=_("Public"), required=False)
    protected = forms.BooleanField(label=_("Protected"), required=False)

    def handle(self, request, data):
        success_images, failure_images = [], []
        for image in self.initial['images']:
            try:
                image = api.glance.image_update(request, image.id, **data)
            except Exception as err:
                logger.error(err)
                failure_images.append(image.name)
            else:
                success_images.append(image.name)

        if failure_images:
            msg = _('Failed to update images: "{0}"')
            messages.error(request, msg.format(u'", "'.join(failure_images)))

        if success_images:
            msg = _('Successfully updated images: "{0}"')
            messages.success(request, msg.format(u'", "'.join(success_images)))

        return True


class AdminCreateImageForm(images_forms.AdminCreateImageForm):
    name = AutoGenNameCharField(max_length=255, label=_("Name"))
