# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard.dashboards.admin.images import tables as admin_tables
from openstack_dashboard.dashboards.project.images.images import (
    tables as project_tables)

from tionix_dashboard.dashboards.admin.images import actions
from tionix_dashboard.helpers.actions import TnxBatchActionMixin


class AdminDeleteImage(TnxBatchActionMixin, admin_tables.AdminDeleteImage):
    pass


class AdminImagesTable(project_tables.ImagesTable):
    name = tables.Column("name",
                         link="horizon:admin:images:detail",
                         truncate=40,
                         verbose_name=_("Image Name"))
    tenant = tables.Column(lambda obj: getattr(obj, 'tenant_name', obj.owner),
                           verbose_name=_("Project"))

    class Meta(object):
        name = "images"
        row_class = admin_tables.UpdateRow
        status_columns = ["status"]
        verbose_name = _("Images")
        table_actions = (admin_tables.AdminCreateImage,
                         AdminDeleteImage,
                         actions.TnxAdminImageFilterAction)
        table_actions_menu = (actions.MultiImageEditAction,)
        row_actions = (admin_tables.AdminEditImage,
                       admin_tables.UpdateMetadata,
                       AdminDeleteImage)
        columns = ('tenant', 'name', 'image_type', 'status', 'public',
                   'protected', 'disk_format', 'size')
