# coding: utf-8
# pylint:disable=no-member

"""Admin Images tests"""

import mock

from horizon import messages
from openstack_dashboard import api

from tionix_dashboard.dashboards.admin.images import forms, tables
from tionix_dashboard.tests.helpers import BaseAdminClientTestCase


class TnxAdminImagesTablesTest(BaseAdminClientTestCase):

    def test_tnx_images_columns(self):

        table = tables.AdminImagesTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(
                ['multi_select', 'tenant', 'name', 'image_type', 'status',
                 'public', 'protected', 'disk_format', 'size', 'actions']
            )
        )

    def test_tnx_images_actions(self):
        images = self.images.list()

        table = tables.AdminImagesTable(self.request, data=images)

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['filter', 'create', 'multi_edit', 'delete'])
        )

    def test_tnx_images_row_actions(self):
        image = self.images.first()

        table = tables.AdminImagesTable(self.request)

        self.assertListEqual(
            sorted([action.name for action in table.get_row_actions(image)]),
            sorted(['update_metadata', 'edit', 'delete'])
        )


class TnxAdminImagesFormsTest(BaseAdminClientTestCase):

    @mock.patch.object(api.glance, 'image_update')
    @mock.patch.object(messages, 'success')
    @mock.patch.object(messages, 'error')
    def test_multi_update(self, error, success, image_update):
        images = self.tnx_images.list()

        image_update.side_effect = (
            lambda req, _id, **kwargs: self.tnx_images.get(_id)
        )

        data = {'is_public': True, 'protected': False}

        form = forms.MultiImageEditForm(self.request)
        form.initial = {'images': images}

        form.handle(self.request, data)

        self.assertTrue(success.called)
        self.assertFalse(error.called)
