# coding: utf-8

"""Tionix domains forms"""

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import forms
from horizon import messages

from tionix_dashboard.clients.domain_config import TNXDomainConfigClient

logger = logging.getLogger(__name__)


class EditDomainConfiguration(forms.SelfHandlingForm):
    """Domain configuration edit form"""

    url = forms.CharField(label='url', max_length=255)
    user = forms.CharField(label='user', max_length=255)
    user_name_attribute = forms.CharField(
        label='user_name_attribute',
        max_length=255)
    user_objectclass = forms.CharField(
        label='user_objectclass',
        max_length=255)
    user_tree_dn = forms.CharField(label='user_tree_dn', max_length=255)
    password = forms.CharField(
        label='password',
        widget=forms.PasswordInput(render_value=False),
        max_length=255)

    def handle(self, request, data):
        """Create/update domain configuration"""
        result, create = True, self.initial.get('create', True)
        action = (TNXDomainConfigClient.create
                  if create else TNXDomainConfigClient.update)
        try:
            action(request, self.initial['domain_id'], data)
        except Exception as err:
            logger.error(unicode(err))
            result = False
        else:
            if create:
                msg = _('Successfully added configuration.')
            else:
                msg = _('Successfully updated configuration.')
            messages.success(request, msg)
        return result
