# coding: utf-8

"""Tionix domains table"""

from django.forms.fields import BooleanField
from django.template import defaultfilters as filters
from django.utils.translation import pgettext_lazy

from horizon import tables

from openstack_dashboard.dashboards.identity.domains import (
    tables as domains_tables)
from tionix_dashboard.dashboards.identity.domains import actions
from tionix_dashboard.helpers.actions import TnxBatchActionMixin


class EnableDomainsAction(TnxBatchActionMixin,
                          domains_tables.EnableDomainsAction):
    pass


class DisableDomainsAction(TnxBatchActionMixin,
                           domains_tables.DisableDomainsAction):
    pass


class DeleteDomainsAction(TnxBatchActionMixin,
                          domains_tables.DeleteDomainsAction):
    pass


class DomainsTable(domains_tables.DomainsTable):
    """Domain table"""
    enabled = tables.Column(
        'enabled',
        verbose_name=pgettext_lazy("Enabled field for domains", u"Enabled"),
        status=True,
        filters=(filters.yesno, filters.capfirst),
        form_field=BooleanField(
            label=pgettext_lazy("Enabled field for domains", u"Enabled"),
            required=False),
        update_action=actions.DomainEnabledAction)

    class Meta(domains_tables.DomainsTable.Meta):

        row_class = actions.UpdateRow

        table_actions_menu = (EnableDomainsAction,
                              DisableDomainsAction,
                              actions.DeleteDomainConfigurationAction)

        row_actions = (domains_tables.SetDomainContext,
                       domains_tables.UpdateUsersLink,
                       domains_tables.UpdateGroupsLink,
                       actions.EditDomainLink,
                       EnableDomainsAction,
                       DisableDomainsAction,
                       DeleteDomainsAction,
                       actions.EditConfigurationAction,
                       actions.AddConfigurationAction,
                       actions.DeleteDomainConfigurationAction)
