# coding: utf-8

"""Tionix domains views"""

import logging

from django.core.urlresolvers import reverse_lazy
from django.utils.translation import ugettext_lazy as _

from horizon import forms

from openstack_dashboard import api
from openstack_dashboard.dashboards.identity.domains import (
    views as domain_views)

from tionix_dashboard.dashboards.identity.domains import (
    constants, tables, forms as tnx_domains_forms)
from tionix_dashboard.dashboards.identity.domains import workflows
from tionix_dashboard.dashboards.identity.domains.helpers import (
    get_domain_configuration)

logger = logging.getLogger(__name__)


class IndexView(domain_views.IndexView):
    """"Tionix domains list view"""
    table_class = tables.DomainsTable

    def get_data(self):
        """Retrieve domains filtered by default domain"""
        domains = super(IndexView, self).get_data()
        return [domain for domain in domains
                if domain.id != api.keystone.DEFAULT_DOMAIN]


class EditConfigurationView(forms.ModalFormView):
    """Edit configuration view"""
    form_class = tnx_domains_forms.EditDomainConfiguration
    template_name = constants.DOMAINS_EDIT_CONFIG_TEMPLATE
    modal_header = _('Edit configuration')
    modal_id = 'edit_config_id'
    context_object_name = 'power_devices'
    success_url = reverse_lazy(constants.DOMAIN_INDEX_URL)

    def get_context_data(self, **kwargs):
        """Context data"""
        context = super(EditConfigurationView, self).get_context_data(**kwargs)
        context['domain_id'] = self.kwargs['domain_id']
        return context

    def get_initial(self):
        """Initial data"""
        initial = super(EditConfigurationView, self).get_initial()
        initial.update(**self.kwargs)
        config = get_domain_configuration(self.request,
                                          self.kwargs['domain_id'])
        if config:
            initial['create'] = False
            initial.update(**config.ldap)
        return initial


class UpdateDomainView(domain_views.UpdateDomainView):
    workflow_class = workflows.UpdateDomain


class CreateDomainView(domain_views.CreateDomainView):
    workflow_class = workflows.CreateDomain
