# coding: utf-8

"""Projects utils"""

import logging

from django.core.cache import cache

from openstack_auth import utils

from openstack_dashboard import api, policy

from tionix_dashboard.dashboards.identity.projects.enum import TenantTypeEnum
from tionix_dashboard.helpers.utils import memoize_by_keyword_arg

from tionix_scheduler_client.enums import ObjectGroupEnum


logger = logging.getLogger(__name__)


def remove_project_cache(token):
    """remove token cache"""
    cache.delete(token)


@memoize_by_keyword_arg(('token', ))
def get_project_list(*args, **kwargs):
    """Return tenants list cached by token"""
    is_federated = kwargs.get('is_federated', False)
    sess = kwargs.get('session') or utils.get_session()
    auth_url = utils.fix_auth_url_version(kwargs['auth_url'])
    auth = utils.token_endpoint.Token(auth_url, kwargs['token'])
    client = utils.get_keystone_client().Client(session=sess, auth=auth)

    if utils.get_keystone_version() < 3:
        projects = client.tenants.list()
    elif is_federated:
        projects = client.federation.projects.list()
    else:
        projects = client.projects.list(user=kwargs.get('user_id'))

    projects.sort(key=lambda project: project.name.lower())
    return projects


def patch_project_cache():
    """Patch to update projects cache"""
    utils.get_project_list = get_project_list


def domain_lookup(request):
    """Return dict of available domains"""
    domain_dict = {}
    if policy.check((("identity", "identity:list_domains"),), request):
        try:
            domains = api.keystone.domain_list(request)
        except Exception as err:
            logger.error(unicode(err))
            logger.warn("Pure project admin doesn't have a domain token")
        else:
            domain_dict = {domain.id: domain.name for domain in domains}
    else:

        get_name = policy.check((("identity", "identity:get_domain"),),
                                request)

        domain = api.keystone.get_default_domain(request, get_name=get_name)
        domain_dict = {domain.id: domain.name}
    return domain_dict


def get_project_group_for_schedule(project):
    """Return project type for schedule"""
    return (ObjectGroupEnum.vdi
            if project.tnx_project_type == TenantTypeEnum.VDI
            else ObjectGroupEnum.identity)
