# coding: utf-8
"""Identity users actions"""

from openstack_dashboard import api
from openstack_dashboard import policy
from openstack_dashboard.dashboards.identity.users import (
    tables as users_tables)


class UpdateCell(users_tables.UpdateCell):
    def allowed(self, request, user, cell):
        policy_rule = (("identity", "identity:update_user"),)
        policy_target = {'target.user.domain_id': user.domain_id}
        return (
            api.keystone.keystone_can_edit_user() and
            policy.check(policy_rule, request, target=policy_target) and
            getattr(user, 'enabled', None) is not None
        )


class EditUserLink(users_tables.EditUserLink):
    def allowed(self, request, user):
        return (
            api.keystone.keystone_can_edit_user() and
            getattr(user, 'enabled', None) is not None
        )


class DeleteUsersAction(users_tables.DeleteUsersAction):
    def allowed(self, request, datum):
        allowed = api.keystone.keystone_can_edit_user()
        if datum:
            allowed = (
                allowed and
                datum.id != request.user.id and
                getattr(datum, 'enabled', None) is not None
            )
        return allowed


class ToggleEnabled(users_tables.ToggleEnabled):

    def __init__(self, **kwargs):
        super(ToggleEnabled, self).__init__(**kwargs)
        self.enabled = None

    def allowed(self, request, user=None):
        allowed = api.keystone.keystone_can_edit_user()

        if user:
            self.enabled = getattr(user, 'enabled', None)
            allowed = allowed and self.enabled is not None
            if allowed:
                if self.enabled:
                    self.current_present_action = users_tables.DISABLE
                else:
                    self.current_present_action = users_tables.ENABLE
        return allowed


class ChangePasswordLink(users_tables.ChangePasswordLink):
    def allowed(self, request, user):
        return (
            api.keystone.keystone_can_edit_user() and
            getattr(user, 'enabled', None) is not None
        )
