# coding: utf-8

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions

from keystoneauth1.exceptions.http import NotFound

from openstack_dashboard import api
from openstack_dashboard.utils.identity import IdentityMixIn
from openstack_dashboard.dashboards.identity.users.forms import CreateUserForm

from tionix_dashboard.helpers.fields import AutoGenNameCharField


logger = logging.getLogger(__name__)


class TnxCreateUserForm(IdentityMixIn, CreateUserForm):

    name = AutoGenNameCharField(max_length=255, label=_("User Name"))

    def handle(self, request, data):
        user = super(TnxCreateUserForm, self).handle(request, data)

        msg = _('Unable to add admin domain role to user.')

        domain_id = data.get('domain_id')
        role_id = data.get('role_id')

        if user and domain_id and role_id:
            try:
                role = api.keystone.role_get(request, role_id)
            except NotFound as err:
                logger.error(unicode(err))
                exceptions.handle(request, msg)
            else:
                if role.name in self.get_admin_roles():
                    try:
                        api.keystone.add_domain_user_role(request, user.id,
                                                          role_id, domain_id)
                    except Exception as err:
                        logger.error(unicode(err))
                        exceptions.handle(request, msg)
        return user
