# coding: utf-8
"""Identity users tables"""

from django.utils.translation import ugettext_lazy as _
from horizon import tables, forms

from openstack_dashboard import api
from openstack_dashboard.dashboards.identity.users import (
    tables as users_tables)

from tionix_dashboard.dashboards.identity.users import actions
from tionix_dashboard.dashboards.tionix.vdi.instances import (
    actions as vdi_actions, tables as vdi_tables)


class UserVDIInstancesTable(vdi_tables.BaseVDIInstancesTable):
    """User's vdi instances table"""
    class Meta(object):
        name = "user_vdi_instances"
        verbose_name = _("Associated VDI instances")
        multi_select = False
        table_actions = (vdi_actions.VDIInstanceFilterAction, )


class UsersTable(tables.DataTable):
    STATUS_CHOICES = (
        ("true", True),
        ("false", False)
    )
    name = tables.Column('name',
                         link="horizon:identity:users:detail",
                         verbose_name=_('User Name'),
                         form_field=forms.CharField(),
                         update_action=actions.UpdateCell)
    description = tables.Column(lambda obj: getattr(obj, 'description', None),
                                verbose_name=_('Description'),
                                hidden=users_tables.KEYSTONE_V2_ENABLED,
                                form_field=forms.CharField(
                                    widget=forms.Textarea(attrs={'rows': 4}),
                                    required=False),
                                update_action=actions.UpdateCell)
    email = tables.Column(lambda obj: getattr(obj, 'email', None),
                          verbose_name=_('Email'),
                          form_field=forms.EmailField(required=False),
                          update_action=actions.UpdateCell,
                          filters=(lambda v: users_tables.defaultfilters
                                   .default_if_none(v, ""),
                                   users_tables.defaultfilters.escape,
                                   users_tables.defaultfilters.urlize))

    id = tables.Column('id', verbose_name=_('User ID'),
                       attrs={'data-type': 'uuid'})
    enabled = tables.Column('enabled', verbose_name=_('Enabled'),
                            status=True,
                            status_choices=STATUS_CHOICES,
                            filters=(users_tables.defaultfilters.yesno,
                                     users_tables.defaultfilters.capfirst),
                            empty_value="False")

    if api.keystone.VERSIONS.active >= 3:
        domain_name = tables.Column(
            'domain_name',
            verbose_name=_('Domain Name'),
            attrs={'data-type': 'uuid'})
        enabled = tables.Column('enabled', verbose_name=_('Enabled'),
                                status=True,
                                status_choices=STATUS_CHOICES,
                                filters=(users_tables.defaultfilters.yesno,
                                         users_tables.defaultfilters.capfirst),
                                empty_value="False")

    class Meta(object):
        name = "users"
        verbose_name = _("Users")
        row_actions = (
            actions.EditUserLink,
            actions.ChangePasswordLink,
            actions.ToggleEnabled,
            actions.DeleteUsersAction
        )
        table_actions = (
            users_tables.UserFilterAction,
            users_tables.CreateUserLink,
            actions.DeleteUsersAction
        )
        row_class = users_tables.UpdateRow
