# coding: utf-8
"""Identity users tabs"""

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, tabs
from horizon.utils import memoized

from openstack_dashboard import api, policy

from tionix_dashboard.dashboards.identity.users import tables
from tionix_dashboard.dashboards.license import LicenseController
from tionix_dashboard.dashboards.tionix.vdi.helpers import get_vdi_instances
from tionix_dashboard.helpers.views import (
    ServerFilterTabMixin)

logger = logging.getLogger(__name__)


class OverviewTab(tabs.Tab):
    """User overview tab"""
    name = _("Overview")
    slug = "overview"
    template_name = 'identity/users/_detail_overview.html'

    def get_context_data(self, request, **kwargs):
        context = super(OverviewTab, self).get_context_data(request, **kwargs)
        user = self.tab_group.kwargs['user']
        domain_id = getattr(user, "domain_id", None)
        domain_name = ''
        if api.keystone.VERSIONS.active >= 3:
            try:
                if policy.check((("identity", "identity:get_domain"),),
                                self.request):
                    domain = api.keystone.domain_get(
                        self.request, domain_id)
                    domain_name = domain.name
                else:
                    domain = api.keystone.get_default_domain(self.request)
                    domain_name = domain.get('name')
            except Exception as err:
                logger.error(unicode(err))
                exceptions.handle(self.request,
                                  _('Unable to retrieve project domain.'))
            context["description"] = getattr(user, "description", _("None"))

        context["user"] = user
        tenant = self.get_tenant(user.project_id)
        if tenant:
            context["tenant_name"] = tenant.name
        context["domain_id"] = domain_id
        context["domain_name"] = domain_name
        return context

    @memoized.memoized_method
    def get_tenant(self, project_id):
        tenant = None
        if project_id:
            try:
                tenant = api.keystone.tenant_get(self.request, project_id)
            except Exception as err:
                msg = ('Failed to get tenant %(project_id)s: %(reason)s' %
                       {'project_id': project_id, 'reason': err})
                logger.error(msg)
        return tenant


class InstancesTab(ServerFilterTabMixin, tabs.TableTab):
    """Tab for user vdi instances"""
    table_classes = (tables.UserVDIInstancesTable,)
    name = _('Associated VDI instances')
    slug = 'instances_tab'
    template_name = 'horizon/common/_detail_table.html'
    preload = False

    def get_user_vdi_instances_data(self):
        search_opts = self.get_filters(
            {'tnx_user': self.tab_group.kwargs['user_id']}
        )

        instances = get_vdi_instances(self.request, search_opts)
        return instances

    def allowed(self, request):
        return LicenseController.is_valid(request, LicenseController.VDI)


class UserDetailTabs(tabs.TabGroup):
    """Tionix user details tab group"""
    slug = "tnx_user_details"
    tabs = (OverviewTab,
            InstancesTab)
    sticky = True
