# coding: utf-8
# pylint: disable=no-member

import mock

from openstack_dashboard import api
from openstack_dashboard.test.tests.templates import FakeUser

from tionix_tests.helpers import get_fake_request

from tionix_dashboard.dashboards.identity.users import forms
from tionix_dashboard.tests.helpers import BaseClientTestCase
from tionix_dashboard.dashboards.identity.users import tables


class UserInstancesTablesTest(BaseClientTestCase):

    def test_user_instances_columns(self):

        table = tables.UserVDIInstancesTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(['tenant', 'name', 'ip', 'status', 'state',
                    'tnx_operation_mode', 'tnx_last_session', 'task', 'az',
                    'size'])
        )

    def test_user_instances_actions(self):
        instances = self.tnx_servers.list()

        table = tables.UserVDIInstancesTable(self.request, data=instances)

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['filter_vdi_instances'])
        )

    def test_user_instances_row_actions(self):
        instance = self.tnx_servers.list()[0]

        table = tables.UserVDIInstancesTable(self.request)

        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(instance)]),
            sorted([])
        )


class UsersTableTest(BaseClientTestCase):

    def test_users_actions(self):
        users = self.tnx_users.list()

        table = tables.UsersTable(self.request, data=users)

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['create', 'delete', 'filter'])
        )

    def test_users_row_actions(self):
        user1, user2 = self.tnx_users.list()[:2]
        user1.enabled = True

        table = tables.UsersTable(self.request)

        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(user1)]),
            sorted(['change_password', 'delete', 'edit', 'toggle'])
        )

        self.assertListEqual(
            [action.name for action in table.get_row_actions(user2)], []
        )


class UsersFormsTest(BaseClientTestCase):

    user_data = None

    # pylint: disable=bad-super-call
    def setUp(self):
        super(BaseClientTestCase, self).setUp()

        self.user_data = {'email': '', 'name': '', 'password': '',
                          'project': '', 'enabled': '', 'description': ''}

    @mock.patch.object(api.keystone,
                       'roles_for_user',
                       mock.Mock(return_value=[]))
    @mock.patch.object(api.keystone, 'add_domain_user_role')
    @mock.patch.object(api.keystone, 'role_get')
    @mock.patch.object(api.keystone, 'user_create')
    @mock.patch.object(api.keystone, 'get_default_domain')
    def test_tnx_create_user_admin(self, get_default_domain, create_user,
                                   role_get, add_domain_user_role):
        domain = self.tnx_domains.list()[0]
        user = self.tnx_users.list()[0]
        role = self.roles.list()[0]

        get_default_domain.return_value = domain
        create_user.return_value = user
        role_get.return_value = role

        request = get_fake_request(
            user=FakeUser(),
            is_ajax=True,
            horizon={
                'async_messages': []
            }
        )
        form = forms.TnxCreateUserForm(request, initial={}, roles={})

        data = {'domain_id': domain.id, 'role_id': role.id}
        data.update(self.user_data)

        form.handle(request, data=data)
        self.assertTrue(add_domain_user_role.called)

    @mock.patch.object(api.keystone,
                       'roles_for_user',
                       mock.Mock(return_value=[]))
    @mock.patch.object(api.keystone, 'add_domain_user_role')
    @mock.patch.object(api.keystone, 'role_get')
    @mock.patch.object(api.keystone, 'user_create')
    @mock.patch.object(api.keystone, 'get_default_domain')
    def test_tnx_create_user_simple_user(self, get_default_domain, create_user,
                                         role_get, add_domain_user_role):
        domain = self.tnx_domains.list()[0]
        user = self.tnx_users.list()[0]
        role = self.roles.list()[1]

        get_default_domain.return_value = domain
        create_user.return_value = user
        role_get.return_value = role

        request = get_fake_request(
            user=FakeUser(),
            is_ajax=True,
            horizon={
                'async_messages': []
            }
        )
        form = forms.TnxCreateUserForm(request, initial={}, roles={})

        data = {'domain_id': domain.id, 'role_id': role.id}
        data.update(self.user_data)

        form.handle(request, data=data)
        self.assertFalse(add_domain_user_role.called)
