# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard.dashboards.project.images.images import (
    tables as project_tables)

from tionix_dashboard.helpers.actions import TnxBatchActionMixin


class DeleteImage(TnxBatchActionMixin, project_tables.DeleteImage):
    pass


class ProjectImagesTable(project_tables.ImagesTable):
    name = tables.Column("name",
                         link="horizon:project:images:images:img_detail",
                         truncate=40,
                         verbose_name=_("Image Name"))

    class Meta(object):
        name = "images"
        row_class = project_tables.UpdateRow
        status_columns = ["status"]
        verbose_name = _("Images")
        table_actions = (project_tables.OwnerFilter,
                         project_tables.CreateImage,
                         DeleteImage,)
        launch_actions = ()
        if getattr(project_tables.settings, 'LAUNCH_INSTANCE_LEGACY_ENABLED',
                   False):
            launch_actions = (project_tables.LaunchImage,) + launch_actions
        if getattr(project_tables.settings, 'LAUNCH_INSTANCE_NG_ENABLED',
                   True):
            launch_actions = (project_tables.LaunchImageNG,) + launch_actions
        row_actions = launch_actions + (project_tables.CreateVolumeFromImage,
                                        project_tables.EditImage,
                                        project_tables.UpdateMetadata,
                                        DeleteImage,)
