# coding: utf-8

"""Project instance workflows"""

from django.utils.translation import ugettext_lazy as _

from openstack_dashboard.dashboards.project.instances.workflows import (
    create_instance)

from tionix_dashboard.helpers.fields import AutoGenNameCharField
from tionix_dashboard.helpers.views import RefererRedirectMixin


class SetInstanceDetailsAction(create_instance.SetInstanceDetailsAction):
    name = AutoGenNameCharField(label=_("Instance Name"), max_length=255)

    class Meta(object):
        name = _("Details")
        help_text_template = "project/instances/_launch_details_help.html"


class SetInstanceDetails(create_instance.SetInstanceDetails):
    action_class = SetInstanceDetailsAction


class LaunchInstance(create_instance.LaunchInstance):
    default_steps = (create_instance.SelectProjectUser,
                     SetInstanceDetails,
                     create_instance.SetAccessControls,
                     create_instance.SetNetwork,
                     create_instance.SetNetworkPorts,
                     create_instance.PostCreationStep,
                     create_instance.SetAdvanced)


class CloneInstance(RefererRedirectMixin, LaunchInstance):
    slug = "clone_instance"
    name = _("Clone Instance")
    finalize_button_name = _("Clone")
    success_message = _('Cloned %(count)s named "%(name)s".')
    failure_message = _('Unable to clone %(count)s named "%(name)s".')
    success_url = "horizon:project:instances:index"

    def __init__(self, request=None, context_seed=None, entry_point=None,
                 *args, **kwargs):
        super(CloneInstance, self).__init__(
            request, context_seed, entry_point, *args, **kwargs)

        for step in self.steps:
            for field_name, field in step.action.fields.items():
                value = context_seed.get(field_name)
                if value:
                    field.initial = value
