# coding: utf-8

import logging

from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from horizon import forms
from horizon import messages
from horizon import exceptions

from openstack_dashboard.api import cinder
from openstack_dashboard.dashboards.project.volumes.volumes import (
    forms as volumes_forms)

from tionix_scheduler_client.enums import ObjectTypeEnum

from tionix_dashboard.dashboards.tionix.scheduler.forms import (
    DeleteObjectWithTasksForm)
from tionix_dashboard.helpers.fields import AutoGenNameCharField

logger = logging.getLogger(__name__)


class TnxCreateSnapshotForm(forms.SelfHandlingForm):
    name = AutoGenNameCharField(max_length=255, label=_("Snapshot Name"))
    description = forms.CharField(max_length=255,
                                  widget=forms.Textarea(
                                      attrs={'rows': 4}),
                                  label=_("Description"),
                                  required=False)

    def handle(self, request, data):
        failed, attached, success, volume = [], [], [], None
        for _id in self.initial.get('volumes_ids', []):
            try:
                volume = cinder.volume_get(request, _id)
                force = False
                if volume.status == 'in-use':
                    force = True
                    attached.append(volume.name)
                cinder.volume_snapshot_create(request,
                                              _id,
                                              data['name'],
                                              data['description'],
                                              force=force)
                success.append(volume.name)
            except Exception as err:
                logger.error(unicode(err))
                failed.append(volume.name if volume else _id)
                # pylint: disable=no-member
                if err.code == 413:
                    redirect = reverse(
                        "horizon:project:volumes:index")
                    msg = _(
                        'Requested snapshot would exceed the allowed quota.')
                    exceptions.handle(request,
                                      msg,
                                      redirect=redirect)
        if failed:
            msg = (_('Unable to create volume snapshot for %s.') %
                   ', '.join(failed))
            messages.error(request, msg)

        if attached:
            msg = _('Forcing to create snapshot '
                    'from attached volumes %s.') % ', '.join(attached)
            messages.info(request, msg)

        if success:
            msg = _('Creating volume snapshot for %s.') % ', '.join(
                success)
            messages.success(request, msg)

        return True


class DeleteVolumeForm(DeleteObjectWithTasksForm):
    """ Delete volumes form """

    object_type = ObjectTypeEnum.volume

    def delete(self, request, object_id):
        cinder.volume_delete(request, object_id)


class CreateForm(volumes_forms.CreateForm):
    name = AutoGenNameCharField(max_length=255, label=_("Volume Name"),
                                required=False)


class CreateTransferForm(volumes_forms.CreateTransferForm):
    name = AutoGenNameCharField(max_length=255, label=_("Transfer Name"),
                                required=False)
