# coding: utf-8

from django.forms.fields import BooleanField
from django.template import defaultfilters as filters
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard.dashboards.project.volumes.volumes import (
    tables as volume_tables)

from tionix_dashboard.dashboards.project.project_volumes.helpers import (
    PagedTableFilterMixin)
from tionix_dashboard.dashboards.tionix.scheduler.actions import (
    ProjectVolumeSchedulerMultiAction, ProjectVolumeSchedulerAction)
from tionix_dashboard.dashboards.project.project_volumes.volumes import (
    actions as volumes_actions
)
from tionix_dashboard.helpers.fields import EmptyCharField
from tionix_dashboard.helpers.volume_constants import DELETING_STATUS


class FilterActionVolumesMixin(object):
    """Filtering actions by status"""

    def _filter_action(self, action, request, datum=None):
        """Filters actions"""
        result = True
        if datum:
            result = datum.status.lower() != DELETING_STATUS
        return (result and
                super(FilterActionVolumesMixin, self)._filter_action(action,
                                                                     request,
                                                                     datum))


class TnxVolumesTableBase(FilterActionVolumesMixin,
                          PagedTableFilterMixin,
                          volume_tables.VolumesTable):

    name = tables.Column(
        "name",
        verbose_name=_("Name"),
        link="horizon:project:volumes:volumes:detail",
        form_field=EmptyCharField(max_length=255),
        update_action=volumes_actions.VolumeUpdateCell)

    description = tables.Column(
        "description",
        verbose_name=_("Description"),
        form_field=EmptyCharField(max_length=255),
        update_action=volumes_actions.VolumeUpdateCell)
    bootable = tables.Column(
        'is_bootable',
        verbose_name=_("Bootable"),
        filters=(filters.yesno, filters.capfirst),
        form_field=BooleanField(
            label=_('Bootable'),
            required=False),
        update_action=volumes_actions.VolumeSetBootableAction
    )

    class Meta(object):
        name = "volumes"
        verbose_name = _("Volumes")
        template = '_data_table.html'
        status_columns = ["status"]
        row_class = volume_tables.UpdateRow
        table_actions = (
            volume_tables.CreateVolume,
            volume_tables.AcceptTransfer,
            volumes_actions.VolumeFilterAction)
        table_actions_menu = (
            volumes_actions.TnxMultiDeleteVolume,
            volumes_actions.TnxMultiCreateSnapshot,
            volumes_actions.TnxCreateBackup,
            ProjectVolumeSchedulerMultiAction)
        row_actions = (
            volume_tables.ExtendVolume,
            volume_tables.LaunchVolume,
            volume_tables.EditAttachments,
            volumes_actions.TnxCreateSnapshot,
            volumes_actions.TnxCreateBackup,
            volume_tables.RetypeVolume,
            volume_tables.UploadToImage,
            volume_tables.CreateTransfer,
            volume_tables.DeleteTransfer,
            volumes_actions.TnxDeleteVolume,
            ProjectVolumeSchedulerAction)
