# coding: utf-8

from datetime import datetime, timedelta

import pytz

from django import shortcuts
from django.conf import settings
from django.utils import translation, encoding
from django.utils.translation import (
    ugettext_lazy as _, LANGUAGE_SESSION_KEY)

from horizon import messages

from openstack_dashboard.dashboards.settings.user.forms import UserSettingsForm


def one_year():
    now = datetime.utcnow()
    return now + timedelta(days=365)


class TnxUserSettingsForm(UserSettingsForm):

    def handle(self, request, data):
        response = shortcuts.redirect(request.build_absolute_uri())
        # Language
        lang_code = data['language']
        if lang_code and translation.check_for_language(lang_code):
            if hasattr(request, 'session'):
                request.session[LANGUAGE_SESSION_KEY] = lang_code
                request.session['django_language'] = lang_code
            response.set_cookie(settings.LANGUAGE_COOKIE_NAME, lang_code,
                                expires=one_year())

        # Timezone
        request.session['django_timezone'] = pytz.timezone(
            data['timezone']).zone
        response.set_cookie('django_timezone', data['timezone'],
                            expires=one_year())

        request.session['horizon_pagesize'] = data['pagesize']
        response.set_cookie('horizon_pagesize', data['pagesize'],
                            expires=one_year())

        request.session['instance_log_length'] = data['instance_log_length']
        response.set_cookie('instance_log_length',
                            data['instance_log_length'], expires=one_year())

        with translation.override(lang_code):
            messages.success(request,
                             encoding.force_text(_("Settings saved.")))

        return response
