# coding: utf-8

"""Balancing compute tables"""

from django.template import defaultfilters as filters
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard.dashboards.admin.aggregates.tables import (
    safe_unordered_list)

from tionix_dashboard.helpers.fields import EmptyCharField
from tionix_dashboard.dashboards.admin.hypervisors import (
    actions as hyp_actions)
from tionix_dashboard.helpers.utils import get_resource_template


def get_vcpu(hypervisor):
    return get_resource_template(hypervisor.vcpus, hypervisor.vcpus_used)


def get_ram(hypervisor):
    return get_resource_template(hypervisor.memory_mb,
                                 hypervisor.memory_mb_used)


def get_disk(hypervisor):
    return get_resource_template(hypervisor.local_gb, hypervisor.local_gb_used)


class ComputeHostsTable(tables.DataTable):
    """Compute hosts table"""
    hostname = tables.Column(
        "hypervisor_hostname",
        link="horizon:admin:hypervisors:detail",
        attrs={'data-type': 'naturalSort'},
        verbose_name=_("Hostname"))
    node_title = tables.Column(
        lambda x: unicode(getattr(x, 'tnx_node_title', '')),
        form_field=EmptyCharField(max_length=100),
        verbose_name=_("Node title"),
        update_action=hyp_actions.TnxNodeUpdateCell)
    hypervisor_type = tables.Column(
        "hypervisor_type",
        verbose_name=_("Type"))
    host_aggregates = tables.Column(
        "host_aggregates",
        verbose_name=_('Host aggregates'),
        wrap_list=True,
        filters=(safe_unordered_list,))
    is_reserved = tables.Column(
        "tnx_is_reserved",
        verbose_name=_('Reserved'),
        filters=(filters.yesno, filters.capfirst))
    vcpu = tables.Column(
        get_vcpu,
        verbose_name=_('vCPU'),
        attrs={'data-type': 'percentbar'})
    ram = tables.Column(
        get_ram,
        verbose_name=_('RAM'),
        attrs={'data-type': 'percentbar'})
    disk = tables.Column(
        get_disk,
        verbose_name=_('Disk'),
        attrs={'data-type': 'percentbar'})

    class Meta(object):
        name = "compute_hosts"
        verbose_name = _("Compute hosts")
        row_class = hyp_actions.TnxHypervisorUpdateRow

    # pylint: disable=unused-argument
    def __init__(self, request, data=None, needs_form_wrapper=None, **kwargs):
        super(ComputeHostsTable, self).__init__(request, data=data,
                                                needs_form_wrapper=True,
                                                **kwargs)
