# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard import api

from tionix_dashboard.dashboards.admin.instances.tables import (
    TnxAdminInstancesTable
)
from tionix_dashboard.dashboards.tionix.metrics.instances import actions


class MetricsInstancesTable(TnxAdminInstancesTable):

    name = tables.Column(
        "name",
        link="horizon:admin:instances:detail",
        verbose_name=_("Name")
    )

    # pylint: disable=no-member
    def __init__(self, request, data=None, needs_form_wrapper=None, **kwargs):
        super(MetricsInstancesTable, self).__init__(
            request, data=data, needs_form_wrapper=needs_form_wrapper, **kwargs
        )
        # Project column and filter are visible only for admin
        if not api.keystone.is_domain_admin(request):
            self.columns.pop('tenant')

            self._meta._filter_action.filter_choices = (
                actions.MetricsInstanceFilterAction.filter_choices[1:]
            )
        else:
            self._meta._filter_action.filter_choices = (
                actions.MetricsInstanceFilterAction.filter_choices[:]
            )

    def get_full_url(self):
        return self.request.get_full_path().split('?')[0]

    class Meta(object):
        name = 'instances_metrics'
        verbose_name = _('Instance')
        table_actions = (actions.MetricsInstanceFilterAction,
                         actions.MetricsInstanceSettingsAction)
        row_actions = (actions.MetricsInstanceShowAction,)
        no_data_message = _('No items to display.')
