# coding: utf-8

import logging

from django.core.urlresolvers import reverse_lazy
from django.utils.translation import ugettext_lazy as _

from horizon import exceptions
from horizon import tabs

from openstack_dashboard import api

from tionix_dashboard.clients import TNXServersClient
from tionix_dashboard.clients.base import tenant_list
from tionix_dashboard.dashboards.license import LicenseController
from tionix_dashboard.dashboards.tionix.metrics.instances import (
    tables as instance_tables)
from tionix_dashboard.dashboards.utils import update_instances_list
from tionix_dashboard.helpers.views import ServerFilterTabMixin

logger = logging.getLogger(__name__)


class InstancesMetricsTab(ServerFilterTabMixin,
                          tabs.TableTab):
    """Metrics instances tab."""
    name = _("Instances")
    slug = "instances_metrics_tab"
    template_name = "metrics/_data_table_instance.html"
    table_classes = (instance_tables.MetricsInstancesTable, )
    preload = False

    def get_instances_metrics_data(self):
        instances, tenants = [], []
        search_opts = self.get_filters({})
        is_admin = api.keystone.is_domain_admin(self.request)
        if is_admin:
            search_opts.update(all_tenants=True)

            try:
                tenants = tenant_list(self.request)
            except Exception as err:
                logger.error(unicode(err))
                tenants = []
                msg = _('Unable to retrieve projects list.')
                exceptions.handle(self.request, msg)

            if 'project' in search_opts:
                ten_filter_ids = [t.id for t in tenants
                                  if t.name == search_opts['project']]
                del search_opts['project']
                if ten_filter_ids:
                    search_opts['tenant_id'] = ten_filter_ids[0]
                else:
                    return instances

        try:
            instances = TNXServersClient.list(self.request,
                                              search_opts=search_opts)
        except Exception as exc:
            logger.error(unicode(exc))
            exceptions.handle(self.request,
                              _('Unable to get project instances list.'))
        return update_instances_list(self.request, instances, tenants=tenants)


class MetricsTab(tabs.Tab):
    name = _("Metrics")
    slug = "metrics"
    template_name = "metrics/_detail_metrics.html"

    def get_context_data(self, request, **kwargs):
        context = super(MetricsTab, self).get_context_data(request, **kwargs)

        obj_id = self.tab_group.kwargs['{0}_id'.format(getattr(self.tab_group,
                                                               'obj_type',
                                                               None))]

        context['instance_metrics_url'] = reverse_lazy(
            'horizon:tionix:metrics:instances:data',
            args=[obj_id]
        )
        return context

    def allowed(self, request):
        return LicenseController.is_valid(request, LicenseController.MONITOR)


class MetricsTabs(tabs.TabGroup):
    slug = "metrics_tabs"
    tabs = (InstancesMetricsTab,)
    sticky = True
    show_single_tab = True
