# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from horizon import tables

from tionix_dashboard.helpers.fields import EmptyCharField
from tionix_dashboard.dashboards.tionix.power_devices.actions import (
    CreatePowerDevice, PowerDeviceFilterAction, DeviceTitleUpdateCell,
    TnxInstancesUpdateRow, DeletePowerDeviceMultiAction,
    DeletePowerDeviceAction, ClonePowerDevice)


class PowerDevicesTable(tables.DataTable):
    """Power devices main table."""
    id = tables.Column('id', verbose_name=_('ID'))
    title = tables.Column('title',
                          verbose_name=_('Device title'),
                          form_field=EmptyCharField(max_length=100),
                          update_action=DeviceTitleUpdateCell)
    device_name = tables.Column('device_name', verbose_name=_('Device type'))
    protocol_type = tables.Column('protocol_type',
                                  verbose_name=_('Protocol type'))
    host = tables.Column('host', verbose_name=_('Host'))
    port = tables.Column('port', verbose_name=_('Port'))

    class Meta(object):
        name = 'power_devices'
        verbose_name = _('Power devices')
        table_actions = (PowerDeviceFilterAction,
                         CreatePowerDevice,
                         DeletePowerDeviceMultiAction)
        row_actions = (DeletePowerDeviceAction, ClonePowerDevice)
        row_class = TnxInstancesUpdateRow
