# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from horizon import tabs

from openstack_dashboard import api as os_api

from tionix_dashboard.helpers.views import (
    DTVTnxPaginationMixin, ServerFilterTabMixin)
from tionix_dashboard.dashboards.tionix.scheduler import api
from tionix_dashboard.dashboards.tionix.scheduler.tables import TabTasksTable


class ActiveTasksTab(ServerFilterTabMixin,
                     DTVTnxPaginationMixin,
                     tabs.TableTab):

    name = _("Scheduled Tasks")
    slug = "scheduler"
    table_classes = (TabTasksTable, )
    template_name = "horizon/common/_detail_table.html"
    preload = False

    sort_map = {
        'begin': ('begin_date', 'begin_time')
    }

    def get_scheduler_data(self):

        obj_type = getattr(self.tab_group, 'obj_type', '')
        obj = self.tab_group.kwargs.get(obj_type)

        offset, limit = self.get_offset_limit()

        sort_dir = self.request.session.get(self.sort_dir_param)
        sort_key = self.request.session.get(self.sort_key_param)

        if sort_key:
            sort_key = self.sort_map.get(sort_key, sort_key)
            if not isinstance(sort_key, (list, tuple)):
                sort_key = (sort_key, )
            sort_key = [''.join(['-' if sort_dir == 'desc' else '', key])
                        for key in sort_key]

        is_admin = os_api.keystone.is_domain_admin(self.request)

        query_params = self.get_filters()
        query_params.update(
            subject_id=obj.id if obj else '',
            subject_type=obj_type,
            all_tenants=is_admin
        )

        tasks, self._prev, self._more, self.table.total_count = (
            api.get_scheduled_tasks(self.request, offset, limit, query_params,
                                    sort_key)
        )

        # Fist, last pages identifiers
        self.table.first_marker, self.table.last_marker = (
            0, self.calc_last_marker(self.table.total_count, limit)
        )

        return tasks
