# coding: utf-8

import logging

from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from horizon import tabs, exceptions

from openstack_dashboard.api.keystone import get_effective_domain_id

from tionix_dashboard.clients import TNXSessionsClient
from tionix_dashboard.clients import TNXTenantClient
from tionix_dashboard.clients.exceptions import UrlNotAvailableError
from tionix_dashboard.dashboards.project.project_instances import (
    tabs as tnx_project_tabs)
from tionix_dashboard.dashboards.tionix.metrics.tabs import MetricsTab
from tionix_dashboard.dashboards.tionix.scheduler.tabs import ActiveTasksTab
from tionix_dashboard.dashboards.tionix.vdi.instances.tables import (
    SessionTable)
from tionix_dashboard.helpers.views import ServerFilterTabMixin

logger = logging.getLogger(__name__)


class SessionTab(ServerFilterTabMixin, tabs.TableTab):
    """VDI Instance session tab"""
    name = _("Sessions")
    slug = "session"
    table_classes = (SessionTable, )
    template_name = "horizon/common/_detail_table.html"
    preload = False

    def get_sessions_data(self):

        sessions = []

        instance = self.tab_group.kwargs['instance']

        try:
            tenant = TNXTenantClient.get(self.request, instance.tenant_id)
        except Exception as err:
            logger.error(unicode(err))
            domain_id = get_effective_domain_id(self.request)
        else:
            domain_id = tenant.domain_id
        try:
            sessions = TNXSessionsClient.list(
                self.request,
                instance_id=instance.id,
                domain_id=domain_id)
        except UrlNotAvailableError:
            raise
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Unable to retrieve sessions list.'))

        return sessions


class TnxConsoleTab(tnx_project_tabs.TnxConsoleTab):
    """VDI instance console tab"""
    full_screen_console = 'horizon:tionix:vdi:instances:fullscreen_console'

    def get_full_screen_console(self, instance):
        return reverse(self.full_screen_console, args=(instance.tenant_id,
                                                       instance.id,))


class OverviewTab(tnx_project_tabs.OverviewTab):
    """VDI instance details overview tab with vdi attributes"""

    is_vdi = True
    template_name = "vdi/instances/_detail_overview.html"


class VDIInstanceDetailTabs(tnx_project_tabs.TnxInstanceDetailTabs):
    """Instance details tab group"""
    tabs = (OverviewTab,
            tnx_project_tabs.TnxLogTab,
            TnxConsoleTab,
            tnx_project_tabs.TnxAuditTab,
            ActiveTasksTab,
            MetricsTab,
            tnx_project_tabs.SLATab,
            SessionTab)
