# coding: utf-8

"""Vdi projects tabs"""

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, tabs

from openstack_dashboard import api

from tionix_scheduler_client.enums import ObjectTypeEnum, ObjectGroupEnum

from tionix_dashboard.dashboards.identity.projects import tabs as projects_tabs
from tionix_dashboard.dashboards.tionix.scheduler.tabs import ActiveTasksTab
from tionix_dashboard.dashboards.tionix.vdi.projects import tables

from tionix_dashboard.clients import TNXServersClient
from tionix_dashboard.clients import TNXSessionsClient
from tionix_dashboard.clients.exceptions import UrlNotAvailableError

from tionix_dashboard.helpers.views import ServerFilterTabMixin

logger = logging.getLogger(__name__)


class InstancesAuditTab(projects_tabs.InstancesAuditTab):
    """Tionix audit of instances tab"""

    table_classes = (tables.TnxVDIInstancesAuditLog,)


class SessionTab(ServerFilterTabMixin, tabs.TableTab):
    """VDI Project session tab"""
    name = _("Sessions")
    slug = "session"
    table_classes = (tables.ProjectsSessionTable,)
    template_name = "horizon/common/_detail_table.html"
    preload = False

    def get_project_sessions_data(self):

        instances = []
        instance_sessions = []

        project_id = self.tab_group.kwargs['tenant_id']
        search_opts = {'project_id': project_id}
        if api.keystone.is_domain_admin(self.request):
            search_opts.update({'all_tenants': True})
        try:
            instances = TNXServersClient.list(self.request,
                                              search_opts=search_opts)
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Unable to get project instances list.'))

        if instances:

            instances_id_name = {instance.id: instance.name
                                 for instance in instances}
            try:
                instance_sessions = TNXSessionsClient.list(
                    self.request,
                    instance_id=instances_id_name.keys(),
                    domain_id=self.tab_group.kwargs['project'].domain_id
                )
            except UrlNotAvailableError:
                raise
            except Exception as err:
                logger.error(unicode(err))
                exceptions.handle(self.request,
                                  _('Unable to retrieve sessions list.'))

            for session in instance_sessions:
                session.instance_name = instances_id_name.get(
                    session.instance_id,
                    session.instance_id
                )
                session.project_id = project_id

        return instance_sessions


class ProjectDetailTabs(tabs.TabGroup):
    """Tionix project details tab group"""
    slug = "tnx_project_details"
    tabs = (projects_tabs.OverviewTab,
            projects_tabs.UsageTab,
            InstancesAuditTab,
            ActiveTasksTab,
            projects_tabs.SLATab,
            SessionTab)

    sticky = True
    obj_type = ObjectTypeEnum.project
    obj_group = ObjectGroupEnum.vdi
