(function(){

    $(document).ready(function(){
        modifyingSearchField();
        trimValueBeforeSearchSubmit();
        localizeNumberInput();

        setDefaultDomain();

        // Also apply in modal views.
        horizon.modals.addModalInitFunction(modifyingSearchField);
        horizon.modals.addModalInitFunction(trimValueBeforeSearchSubmit);
        horizon.modals.addModalInitFunction(localizeNumberInput);

        // Also apply in tabs views for lazy-loaded data.
        horizon.tabs.addTabLoadFunction(modifyingSearchField);
        horizon.tabs.addTabLoadFunction(trimValueBeforeSearchSubmit);
        horizon.tabs.addTabLoadFunction(localizeNumberInput);
    });

    window.onpageshow = function() {
        if (horizon.modals.spinner) {
            horizon.modals.spinner.modal('hide');
        }
    };

    function enableClearIcon(elem, val) {
        if (val) {
            elem.addClass('fa-remove');
        } else {
            elem.removeClass('fa-remove');
        }
    }

    /*
    * Add remove icon to search input
    */
    function modifyingSearchField() {
        var tableSearch = $('div.table_search');

        // Client client search
        var clientSearchInput = tableSearch.filter('.client').find('input');

        clientSearchInput.next('span.search-icon').on('click', function (event) {
            var input = $(event.target);
            if (input.hasClass('fa-remove')) {
                clientSearchInput.val('').trigger('keyup');
                enableClearIcon(input, event.target.value);
            }
        });

        tableSearch.find('input').on('keyup', function (event) {
            var nextElement = $(event.target).next('span.search-icon');
            enableClearIcon(nextElement, event.target.value);
        });

        // Server side search
        var serverSearchInput = tableSearch.filter(':not(.client)').find('input').not(':hidden');
        var searchAction = tableSearch.filter(':not(.client)').find('input[name=search_action]');
        serverSearchInput.trigger('keyup');

        serverSearchInput.next('span.search-icon').on('click', function (event) {
            if ($(event.target).hasClass('fa-remove')) {
                serverSearchInput.val('');
                searchAction.val('reset');
                enableClearIcon($(event.target), event.target.value);
                tableSearch.find('button').click();
            }
        });
    }

    /*
    * Remove leading and trailing whitespaces before search for server side search
    */
    function trimValueBeforeSearchSubmit() {
        var tableSearch = $('div.table_search');
        var button = $('.table_search_button'),
            form = button.parents('form')[0];

        if (form){
            form.addEventListener('submit', function(e){
                var input = $(e.target).find('.table_search.server').find('input').not(':hidden');
                input.val(input.val().trim());

                var searchAction = tableSearch.filter(':not(.client)').find('input[name=search_action]');
                if(searchAction.val() != 'reset')
                    searchAction.val('button')
            });
        }

    }

    /*
    * Localize more/less messages in number fields
    * */
    function localizeNumberInput() {

        var minTemplate = gettext("Value must be less than or equal to %s."),
          maxTemplate = gettext("Value must be greater than or equal to %s."),
          notNumberMsg = gettext("Please enter a number."),
          stepMsg = gettext("Please enter a valid value.");

        $('input[type="number"]').bind('input', function(event) {
            var input = event.target, msg;
            input.setCustomValidity("");
            if (!input.checkValidity()) {
                if (input.validity.rangeOverflow) {
                    msg = interpolate(minTemplate, [input.max]);
                    input.setCustomValidity(msg);
                } else if (input.validity.rangeUnderflow) {
                    msg = interpolate(maxTemplate, [input.min]);
                    input.setCustomValidity(msg);
                } else if (input.validity.badInput) {
                    input.setCustomValidity(notNumberMsg);
                } else if (input.validity.stepMismatch) {
                    input.setCustomValidity(stepMsg);
                }
            }
        });
    }

    function setDefaultDomain() {
        var $form = $('.login form');

        $form.submit(function() {
            var $domainInput = $(this).find('input#id_domain');

            if (!$domainInput.val()) {
                $domainInput.val(horizon.defaultDomain);
            }
        });
    }

    $.extend({
        servertablesorter: new function() {
            var ts = this;

            ts.defaults = {
                selector: '> thead th, > thead td',
                headerClass: 'tablesorter-header ',
                sortedOrderAttr: 'data-sort-dir',
                sortedkeyAttr: 'data-sort-key',
                sortAsc : 'tablesorter-headerAsc',
                sortDesc: 'tablesorter-headerDesc'
            };

            ts.constructor = function(options) {
                return this.each(function() {
                    var $table = $(this),
                        c = $.extend(true, {}, ts.defaults, options);
                    ts.setUp($table, c);
                });
            };

            ts.setUp = function($table, c) {
                var $headers = $table.find(c.selector),
                    sortOrder = $table.attr(c.sortedOrderAttr),
                    sortKey = $table.attr(c.sortedkeyAttr);

                $headers.addClass(c.headerClass);

                $headers.bind('click', function() {
                    var $header = $(this),
                        form = $table.parents('form').first();
                    if ($header.hasClass('sortable')) {
                        var sortOrder = $header.hasClass(c.sortAsc) ? 'desc' : 'asc';
                        addFakeField($table, sortOrder, $header.attr('data-column'));
                        form.submit();
                    }
                });

                $headers.filter('[data-column=' + sortKey + ']').each(function(){
                    var $header = $(this);
                    $header.addClass(sortOrder == 'desc' ? c.sortDesc : c.sortAsc)
                });

                $headers.filter('[data-column]').each(function(){
                    $(this).html('<div class="tablesorter-header-inner">' + $(this).html() + '</div>');
                });

            };

            function addFakeField($table, sortOrder, sortKey) {
                var html = '<input type="hidden" name="sort_dir" value="' + sortOrder + '">' +
                    '<input type="hidden" name="sort_key" value="' + sortKey + '">';
                $table.append(html);
            }
        }()
    });

    var ts = $.servertablesorter;

    $.fn.extend({
        servertablesorter: ts.constructor
    });

}());