/**
 * Created by user on 31.01.17.
 */
(function () {
  'use strict';

  angular
    .module('horizon.app.core.openstack-service-api')
    .factory('horizon.app.core.openstack-service-api.tnx', tnxAPI);

  tnxAPI.$inject = [
    'horizon.framework.util.http.service',
    'horizon.framework.widgets.toast.service'
  ];

  function tnxAPI(apiService, toastService) {
    var service = {
      getTnxServer: getTnxServer,
      createTnxServer: createTnxServer,
      getAggregatesByProject: getAggregatesByProject
    };

    return service;

    /**
     * @name horizon.app.core.openstack-service-api.tnx.getTnxServer
     * @description
     * Get a single tnx extended server by ID
     * @param {string} serverId
     * Specifies the id of the server to request.
     */
    function getTnxServer(serverId) {
      return apiService.get('/api/tnx/servers/' + serverId)
        .error(function () {
          toastService.add('error', gettext('Unable to retrieve the server.'));
        });
    }

    /**
     * @name horizon.app.core.openstack-service-api.tnx.createTnxServer
     * @description
     * Create a server using the parameters supplied in the
     * newServer. The required parameters:
     *
     * "name", "source_id", "flavor_id", "key_name", "user_data"
     *     All strings
     * "security_groups"
     *     An array of one or more objects with a "name" attribute.
     *
     * Other parameters are accepted as per the underlying novaclient:
     * "block_device_mapping", "block_device_mapping_v2", "nics", "meta",
     * "availability_zone", "instance_count", "admin_pass", "disk_config",
     * "config_drive"
     *
     * This returns the new server object on success.
     */
    function createTnxServer(newServer) {
      return apiService.post('/api/tnx/servers/', newServer)
        .error(function () {
          toastService.add('error', gettext('Unable to create the server.'));
        });
    }

    /**
     * @name horizon.app.core.openstack-service-api.tnx.getTnxServer
     * @description
     * Get list of aggregates by project ID
     * @param {string} projectId
     * Specifies the id of the server to request.
     */
    function getAggregatesByProject(projectId) {
      return apiService.get('/api/tnx/aggregates/' + projectId + '/')
        .error(function () {
          var msg = gettext('Unable to retrieve the aggregates.');
          toastService.add('error', msg);
        });
    }

  }

}());