# coding: utf-8

"""
module contain fake cloud state, with hypervisors, servers e.t.c
"""

from openstack_dashboard.api.keystone import DEFAULT_DOMAIN

cloud_state = {
    'hypervisors': [
        {
            'id': 1,
            'hypervisor_hostname': 'Host1',
            'tnx_node_title': 'Host1',
            'tnx_devices': [('device 1', 'port 1', True, True, 1)],
            'tnx_power_state': None,
            'hypervisor_type': None,
            'tnx_image_name': 'image name',
            'tnx_is_reserved': False,
            'running_vms': 0,
            'state': 'up',
            'status': 'enabled',
            'cpu_info': '',
            'service': {'host': 'Host1', 'zone': 'nova'}
        }, {
            'id': 2,
            'hypervisor_hostname': 'Host2',
            'tnx_devices': [('device 2', 'port 1', True, True, 1)],
            'tnx_power_state': 'power_on',
            'state': 'up',
            'service': {'host': 'Host2', 'zone': 'nova'},
            'vcpus': 10,
            'vcpus_used': 2,
            'memory_mb': 10,
            'memory_mb_used': 2,
            'local_gb': 10,
            'local_gb_used': 2
        }, {
            'id': 3,
            'hypervisor_hostname': 'Host3',
            'tnx_devices': [('device 2', 'port 1', True, True, 1)],
            'tnx_power_state': None,
            'state': 'down',
            'service': {'host': 'Host3'}
        }, {
            'id': 4,
            'hypervisor_hostname': 'Host4',
            'tnx_node_title': 'Host4',
            'tnx_devices': [('device 2', 'port 1', True, True, 1)],
            'tnx_power_state': 'power_off',
            'state': 'down',
            'status': 'enabled',
            'service': {'host': 'Host4'}
        },
        # hypervisors without tnx fields
        {
            'id': 5,
            'hypervisor_hostname': 'Host5',
            'hypervisor_type': None,
            'tnx_devices': [],
            'running_vms': 0,
            'state': 'up',
            'status': 'enabled',
            'cpu_info': '',
            'service': {'host': 'Host5'}
        }, {
            'id': 6,
            'hypervisor_hostname': 'Host6',
            'tnx_devices': [],
            'state': 'up',
            'service': {'host': 'Host6'}
        }, {
            'id': 7,
            'hypervisor_hostname': 'Host7',
            'state': 'down',
            'service': {'host': 'Host7'},
            'tnx_devices': [],
        }, {
            'id': 8,
            'hypervisor_hostname': 'Host8',
            'state': 'down',
            'status': 'enabled',
            'service': {'host': 'Host8'},
            'tnx_devices': [],
        },
    ],
    'hypervisor_images': [
        'default'
    ],
    'servers': [
        {
            'id': 1,
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 1,
            'OS-EXT-STS:task_state': None,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'ACTIVE',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1',
            'tnx_node_title': 'Node1',
            'node_id': 10,
            'tnx_movable': False,
            'log_output': 'Test data',
            'key_name': 'test key name',
            'availability_zone': 'nova',
            'tnx_users': [{'id': 1}]
        },
        {
            'id': 2,
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 0,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {
                'test_net': [{
                    'addr': '192.0.0.1'
                }]
            },
            'status': 'ACTIVE',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 3,
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 1,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'ERROR',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 4,
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 0,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'PAUSED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 5,
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 0,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'SUSPENDED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 6,
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 0,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'SHELVED_OFFLOADED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 7,
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 3,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'PAUSED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 8,
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 7,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'SUSPENDED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 9,
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 7,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'VERIFY_RESIZE',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 10,
            'OS-EXT-SRV-ATTR:host': 'Host2',
            'OS-EXT-STS:power_state': 1,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'SHUTOFF',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': 11,
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host5',
            'OS-EXT-STS:power_state': 1,
            'OS-EXT-STS:task_state': None,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 2
            },
            'addresses': {},
            'status': 'ACTIVE',
            'created': '2016-07-10 10:30:00',
            'node_id': 10,
            'log_output': 'Test data',
            'key_name': 'test key name',
            'availability_zone': 'nova',
        },
        {
            'id': 12,
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host5',
            'OS-EXT-STS:power_state': 1,
            'OS-EXT-STS:task_state': None,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 3
            },
            'addresses': {},
            'status': 'PAUSED',
            'created': '2016-07-10 10:40:00',
            'node_id': 10,
            'log_output': 'Test data',
            'key_name': 'test key name',
            'availability_zone': 'nova',
        },
        {
            'id': 13,
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host5',
            'OS-EXT-STS:power_state': 1,
            'OS-EXT-STS:task_state': None,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 3
            },
            'addresses': {},
            'status': 'ERROR',
            'created': '2016-07-10 10:40:00',
            'node_id': 10,
            'log_output': 'Test data',
            'key_name': 'test key name',
            'availability_zone': 'nova',
        },
    ],
    'flavors': [
        {
            'id': 1,
            'name': 'Flavor 1',
            'ram': 512,
            'disk': 50,
            'vcpus': 1,
            'is_public': True
        },
        {
            'id': 2,
            'name': 'Flavor 2',
            'ram': 512,
            'disk': 50,
            'vcpus': 1,
            'is_public': False

        }
    ],
    'images': [
        {
            'id': 1,
            'name': 'Image 1',
            'container_format': '',
            'size': 1,
            'min_disk': 1,
            'protected': False,
            'status': 'active',
            'owner': '1',
            'is_public': True
        },
        {
            'id': 2,
            'name': 'Image 2',
            'container_format': 'aki',
            'size': 1,
            'min_disk': 1,
            'protected': True,
            'status': 'not active',
            'owner': '2',
            'is_public': False
        },
        {
            'id': 3,
            'name': 'Image 3',
            'container_format': 'aki',
            'size': 1,
            'min_disk': 1,
            'protected': False,
            'status': 'not active',
            'owner': '1',
            'is_public': True
        }
    ],
    'power_devices': [
        {
            'id': 1,
            'name': 'Power device 1',
            'title': 'Power device 1',
            'device_name': 'type 1',
            'protocol_type': 'protocol 1'
        },
        {
            'id': 2,
            'name': 'Power device 2',
            'title': 'Power device 2',
            'device_name': 'type 1',
            'protocol_type': 'protocol 2'

        },
        {
            'id': 3,
            'name': 'New device',
            'title': 'New device',
            'device_name': 'type 2',
            'protocol_type': 'protocol 3'
        },

    ],
    'tenants': [
        {'id': '1',
         'name': 'Tenant 1',
         'tnx_operation_mode': 1,
         'tnx_flavor_id': 1,
         'tnx_network_id': 1,
         'tnx_image_id': 1,
         'description': 'description',
         'domain_name': 'domain name',
         'enabled': 'yes',
         'tnx_project_type': 'vdi type'},
        {'id': '2',
         'name': 'Tenant 2',
         'tnx_operation_mode': 1,
         'tnx_flavor_id': 2,
         'tnx_network_id': 2,
         'tnx_image_id': 1},
        {'id': '3',
         'name': 'Tenant 3',
         'tnx_operation_mode': 1,
         'tnx_flavor_id': 1,
         'tnx_network_id': 3,
         'tnx_image_id': 1},
        {'id': '4',
         'name': 'Tenant 4',
         'tnx_operation_mode': 1,
         'tnx_flavor_id': 1,
         'tnx_network_id': 3,
         'tnx_image_id': 2}
    ],

    'networks': [
        {'id': 1,
         'tenant_id': 1,
         'shared': True},
        {'id': 2,
         'tenant_id': 1,
         'shared': False},
        {'id': 3,
         'tenant_id': 1,
         'shared': True},
    ],
    'quotas': [
        {'id': 1,
         'instances': 10},
        {'id': 2,
         'instances': 10},
        {'id': 3,
         'instances': 10},
        {'id': 4,
         'instances': 5},
    ]
}

keystone_state = {
    'domains': [
        {'id': 1,
         'name': 'domain 1',
         'enabled': True},
        {'id': 2,
         'name': 'domain 2',
         'enabled': False},
        {'id': DEFAULT_DOMAIN,
         'name': 'domain_3',
         'enabled': True}
    ],

    'users': [
        {'id': 1,
         'name': 'user 1',
         'domain_id': 1},
        {'id': 2,
         'name': 'user 2',
         'domain_id': 1},
        {'id': 3,
         'name': 'user 3',
         'domain_id': 2},
        {'id': 4,
         'name': 'user 4',
         'domain_id': 3}
    ]
}

HYPERVISOR_COUNT = len(cloud_state['hypervisors'])
ALL_SERVERS_COUNT = len(cloud_state['servers'])
SERVERS_COUNT = {}
for hypervisor in cloud_state['hypervisors']:
    hypervisor_hostname = hypervisor['hypervisor_hostname']
    count = len([server for server in cloud_state['servers']
                 if server['OS-EXT-SRV-ATTR:host'] == hypervisor_hostname])
    SERVERS_COUNT[hypervisor_hostname] = count
POWER_DEVICE_COUNT = len(cloud_state['power_devices'])
