# coding: utf-8

import importlib
import os
import unittest

from tionix_dashboard.helpers.i18 import ugettext as _
from tionix_dashboard.tests.functional import FunctionalTests


@unittest.skipIf(not FunctionalTests.active,
                 u'functional tests do not apply in this case')
class LocalizationTestCase(unittest.TestCase):
    def test_localization_files(self):
        """Check localization files existence.

        :lang:ru Проверка существования файлов локализации.
        """

        mo_location = u'locale/ru/LC_MESSAGES/'

        package_files = [
            (u'horizon', [u'django.mo', u'djangojs.mo']),
            (u'openstack_auth', [u'django.mo']),
            (u'openstack_dashboard', [u'django.mo', u'djangojs.mo']),
            (u'tionix_dashboard', [u'django.mo', u'djangojs.mo']),
        ]

        failed_packages, failed_files = [], []
        for package_name, files in package_files:
            package_path = self.get_module_path(package_name)
            if not package_path:
                failed_packages.append(package_name)
            else:
                for file_name in files:
                    file_path = os.path.join(
                        package_path, mo_location, file_name)
                    if not os.path.exists(file_path):
                        failed_files.append(file_path)

        if failed_packages:
            self.fail(_(
                u'Unable to find packages location: {0}. '
                u'Please make sure that they are installed.').format(
                    u', '.join(failed_packages)))
        if failed_files:
            self.fail(_(
                u"Localization files are missing:\n{0}\nPlease run "
                u"`python /usr/share/openstack-dashboard/manage.py "
                u"compilemessages`").format(u'\n'.join(failed_files)))

    @staticmethod
    def get_module_path(module_name):
        path = None
        try:
            module = importlib.import_module(module_name)
        except ImportError:
            pass
        else:
            path = os.path.dirname(module.__file__)
        return path
