# coding: utf-8

import getpass
import os

import logging

from django.conf import settings

from tionix_dashboard.helpers.i18 import ugettext as _
from tionix_client.os_clients.glance_client import get_glance_client
from tionix_client.os_clients.keystone_client import get_keystone_client
from tionix_client.os_clients.nova_client import get_nova_client
from tionix_client.tests.functional.base import BaseClientTestCase, ServiceType

test_not_available_msg = _(u'Test not available for '
                           u'user "{0}"').format(getpass.getuser())


logger = logging.getLogger(__name__)


class BaseDashTestCase(BaseClientTestCase):

    _keystone_client = None
    _nova_client = None
    _glance_client = None

    @staticmethod
    def get_auth_params():
        params = {}

        token = os.environ.get('OS_TOKEN')
        if token:
            params['token'] = token
        else:
            params.update({
                'username': settings.KEYSTONE['auth_user'],
                'password': settings.KEYSTONE['auth_password'],
                'user_domain_name': settings.KEYSTONE['user_domain_name'],
            })

        project_id = os.environ.get('OS_PROJECT_ID')
        if project_id:
            params['tenant_id'] = project_id
        else:
            params.update({
                'tenant': settings.KEYSTONE['auth_tenant'],
                'project_domain_name': settings.KEYSTONE['project_domain_name']
            })
        return params

    @property
    def keystone_client(self):
        if not self._keystone_client:
            self.auth_params = self.get_auth_params()
            try:
                client = get_keystone_client(**self.auth_params)
            except Exception as err:
                logger.error(unicode(err))
                self.fail_with_params(ServiceType.KEYSTONE,
                                      self.service_connection_msg)
            else:
                self._keystone_client = client
        return self._keystone_client

    @property
    def nova_client(self):
        if not self._nova_client:
            try:
                client = get_nova_client(keystone_client=self.keystone_client)
            except Exception as err:
                logger.error(unicode(err))
                self.fail_with_params(ServiceType.NOVA,
                                      self.service_connection_msg)
            else:
                self._nova_client = client
        return self._nova_client

    @property
    def glance_client(self):
        if not self._glance_client:
            try:
                client = get_glance_client(
                    keystone_client=self.keystone_client)
            except Exception as err:
                logger.error(unicode(err))
                self.fail_with_params(ServiceType.GLANCE,
                                      self.service_connection_msg)
            else:
                self._glance_client = client
        return self._glance_client
